summaryrefslogtreecommitdiff
path: root/test/files/run/finally.scala
diff options
context:
space:
mode:
Diffstat (limited to 'test/files/run/finally.scala')
-rw-r--r--test/files/run/finally.scala6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/files/run/finally.scala b/test/files/run/finally.scala
index 2c01edaaef..467c9e5868 100644
--- a/test/files/run/finally.scala
+++ b/test/files/run/finally.scala
@@ -93,8 +93,8 @@ object Test extends App {
}
}
- // nested finallies with return value
- def nestedFinalies: Int =
+ // nested finally blocks with return value
+ def nestedFinallyBlocks: Int =
try {
try {
return 10
@@ -123,5 +123,5 @@ object Test extends App {
test(throwBody, "throwBody")
test(retFinally, "retFinally")
test(throwFinally, "throwFinally")
- test(nestedFinalies, "nestedFinalies")
+ test(nestedFinallyBlocks, "nestedFinallyBlocks")
}